@@ -127,7 +127,7 @@ bool Bayonne::loadPlugin(const char *path)
 #ifdef	WIN32
 #ifdef	HAVE_TESTING
         if(!prefix && provision_test)
-#ifdef  NDEBUG
+#ifdef  _DEBUG
                 prefix = "DEBUG";
 #else
                 prefix = "RELEASE";
@@ -197,14 +197,14 @@ bool Bayonne::loadMonitor(const char *path)
 #ifdef	WIN32
 #ifdef	HAVE_TESTING
         if(!prefix && provision_test)
-#ifdef  NDEBUG
+#ifdef  _DEBUG
                 prefix = "DEBUG";
 #else
                 prefix = "RELEASE";
 #endif 
 #endif
 	if(!prefix)
-		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Monitor";
+		prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Monitors";
 #else
         char prefixbuf[256];
 
