@@ -337,6 +337,7 @@ public:
 		RESTART_LIBEXEC,
 		TONE_LIBEXEC,
 		XFER_LIBEXEC,
+		POST_LIBEXEC,
 
 		// primary driver events
 
@@ -612,6 +613,7 @@ public:
 			struct
 			{
 				timeout_t interdigit;
+				timeout_t lastdigit;
 				const char *var;
 				const char *exit;
 				const char *format;
@@ -852,56 +854,6 @@ public:
 	static void errlog(const char *level, const char *fmt, ...); 
 };
 
-/**
- * A core class to support audio feeds that can be used in continues
- * audio processing, whether to feed background music, or other audio
- * source overlays.
- */
-class __EXPORT BayonneFeeder : public Audio, protected ThreadLock
-{
-protected:
-	static BayonneFeeder *first;
-	BayonneFeeder *next;
-
-	Sample buffer[MAX_AUDIOFEED];
-	const char *id;
-	unsigned pos, last;
-	unsigned count;
-	bool active;
-
-	void setEnding(void);
-
-	Linear putBuffer(unsigned size);
-
-public:
-	BayonneFeeder(const char *name);
-
-	/**
-	 * Get if encoding is native or not.
-	 *
-	 * @return true if native endian, else linear former...
-	 */
-	virtual bool isNative(void) = 0;
-
-	/**
-	 * Get last position to use.
-	 *
-	 * @return offset for getBuffer work...
-	 */
-	unsigned getPosition(void);
-
-	/**
-	 * Get a buffer for our offset.
-	 *
-	 * @param offset.
-	 * @param size we request.
-	 * @return first sample or NULL if inactive.
-	 */
-	Linear getBuffer(unsigned offset, unsigned size);
-
-	static BayonneFeeder *get(const char *id);
-};
-
 /**
  * A core class to support language translation services in Bayonne
  * phrasebook.
@@ -1834,14 +1786,6 @@ protected:
 	 */
 	virtual void disableDTMF(void);
 
-	/**
-	 * Set continues audio feed if allowed.
-	 *
-	 * @param feed to set or NULL to clear.
-	 * @return true if successful.
-	 */
-	virtual bool setFeeder(BayonneFeeder *feeder);
-
 	/**
 	 * Check audio properties for file and channel audio processing
 	 * based on the driver specific capabilities of this channel
