@@ -482,9 +482,14 @@ input:
                         }
                         while(size < MAX_DTMF && copy < count)
                                 data[size++] = dtmf_digits[copy++];
+
+			data[size] = 0;
                 }
                 else
+		{
                         memcpy(data, dtmf_digits, count);
+			data[count] = 0;
+		}
 
                 pos = 0;
                 while(count + pos <= digit_count)
@@ -504,7 +509,7 @@ input:
 
 bool BayonneSession::stateInput(Event *event)
 {
-	unsigned count, copy, size;
+	unsigned count, copy, size, last;
 	char data[MAX_DTMF + 1];
 	const char *cp;
 	signal_t trapkey;
@@ -535,13 +540,21 @@ bool BayonneSession::stateInput(Event *event)
 	case ENTER_STATE:
 		stopTimer();
 		if(state.input.exit)
+		{
+			last = state.input.count;
 			count = getInputCount(state.input.exit, state.input.count + 1);
+		}
 		else
+		{
+			last = state.input.count - 1;
 			count = getInputCount(state.input.exit, state.input.count);
+		}
 
 		if(!count)
 		{
-			if(digit_count)
+                        if(digit_count && digit_count == last)
+                                state.timeout = state.input.lastdigit; 
+			else if(digit_count)
 				state.timeout = state.input.interdigit;
 
 			startTimer(state.timeout);
@@ -586,9 +599,13 @@ input:
 			}
 			while(size < MAX_DTMF && copy < count)
 				data[size++] = dtmf_digits[copy++];
+			data[size] = 0;
 		}
 		else
+		{
 			memcpy(data, dtmf_digits, count);
+			data[count] = 0;
+		}
 
 
 		dtmf_digits[0] = 0;
@@ -648,7 +665,9 @@ bool BayonneSession::stateRead(Event *event)
 
 		if(!count)
 		{
-			if(digit_count)
+                        if(digit_count && digit_count == state.input.count - 1)
+                                state.timeout = state.input.lastdigit;   
+			else if(digit_count)
 				state.timeout = state.input.interdigit;
 
 			startTimer(state.timeout);
@@ -846,63 +865,9 @@ bool BayonneSession::stateTone(Event *event)
 
 bool BayonneSession::stateDTMF(Event *event)
 {
-	Event ev;
-
-	if(event->id != TIMER_EXPIRED)
-		if(enterDTMF(event))
-			return true;
-
-	switch(event->id)
-	{
-	case ENTER_STATE:
-		state.tone.flashing = false;
-		if(!state.tone.syncdigit || !*state.tone.syncdigit)
-			return true;
-		if(!state.tone.synctimer || state.tone.synctimer == TIMEOUT_INF)
-			return true;
-	case TIMER_EXPIRED:
-		if(!*state.tone.syncdigit)
-			return true;
-		memset(&ev, 0, sizeof(ev));
-		ev.id = DTMF_KEYSYNC;
-		ev.dtmf.duration = state.tone.synctimer / 2;
-		ev.dtmf.digit = *state.tone.syncdigit - '0';
-		enterDTMF(&ev);				
-		++state.tone.syncdigit;
-		startTimer(state.tone.synctimer);
-		return true;
-	case AUDIO_IDLE:
-		if(state.tone.exiting)
-		{
-			setState(STATE_HANGUP);
-			return true;
-		}
-		if(setLibreset(RESULT_COMPLETE))
-			return true;
-
-		advance();
-		setRunning();
-		return true;
-	case LINE_HANGUP:
-		if(state.tone.flashing)
-			return false;
-		break;
-	case START_FLASH:
-		state.tone.flashing = true;
-		setOffhook(false);
-		break;
-	case STOP_FLASH:
-		setOffhook(true);
-		state.tone.flashing = false;
-		break;
-	case TONE_START:
-		return false;
-	}
-
-	return enterCommon(event);
+	return stateTone(event);
 }
 
-
 bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
@@ -1060,7 +1025,7 @@ bool BayonneSession::stateRecord(Event *event)
 		*dtmf_digits = 0;
 		state.audio.trigger = false;
 
-		if(state.audio.exit || state.audio.exitkey)
+		if(state.audio.exit || state.audio.exitkey || state.audio.menu)
 			dtmf = enableDTMF();
 
 		if(state.audio.silence)
@@ -1086,29 +1051,26 @@ bool BayonneSession::stateRecord(Event *event)
 		return true;
 	case DTMF_KEYUP:
 		key = getChar(event->dtmf.digit);
-		if(state.audio.exit)
-			if(strchr(state.audio.exit, key))
+		if(state.audio.exit && strchr(state.audio.exit, key))
+		{
+			snprintf(evtmsg, sizeof(evtmsg), "exitkey:%c", key);
+			if(scriptEvent(evtmsg))
 			{
-				snprintf(evtmsg, sizeof(evtmsg), "exitkey:%c", key);
-				if(scriptEvent(evtmsg))
-				{
-					setRunning();
-					return true;
-				}
+				setRunning();
+				return true;
 			}
-			else
-				goto exitkey;
+			goto exitkey;
+		}
 
-		if(state.audio.menu)
-			if(strchr(state.audio.menu, key))
+		if(state.audio.menu && strchr(state.audio.menu, key))
+		{
+			snprintf(evtmsg, sizeof(evtmsg), "recordkey:%c", key);
+			if(scriptEvent(evtmsg))
 			{
-				snprintf(evtmsg, sizeof(evtmsg), "recordkey:%c", key);
-				if(scriptEvent(evtmsg))
-				{
-					setRunning();
-					return true;
-				}
+				setRunning();
+				return true;
 			}
+		}
 
 		if(state.audio.exitkey)
 		{
@@ -1638,6 +1600,7 @@ bool BayonneSession::stateRunning(Event *event)
 	switch(event->id)
 	{
 	case ENTER_STATE:
+		check();
 		if(!starting)
 		{
 			event->id = seizure;
@@ -1758,6 +1721,7 @@ bool BayonneSession::stateHangup(Event *event)
 bool BayonneSession::filterPosting(Event *event)
 {
 	BayonneSession *pid;
+	Line *line;
 
 	switch(event->id)
 	{
@@ -1771,6 +1735,9 @@ bool BayonneSession::filterPosting(Event *event)
 	case DTMF_KEYDOWN:
 		if(!dtmf || !dtmf_digits)
 			return false;
+                line = getLine();
+                if(line && !(line->mask & 0x08))
+                        return false;     
 		digit_count = strlen(dtmf_digits);
 		return true;
 	case STOP_PARENT:
@@ -1870,6 +1837,13 @@ bool BayonneSession::enterCommon(Event *event)
 			return true;
 		}
 		return false;
+        case POST_LIBEXEC:
+                if(scriptEvent(event->name))
+                {
+                        setRunning();
+                        return true;
+                }
+                return false;  
 	case PEER_WAITING:
 		if(scriptEvent("start:waiting"))
 		{
