@@ -199,8 +199,13 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		AudioCodec::endCodec(codec);
 	}	
 
+#ifdef	WIN32
+        server->setValue("sip.conf", CONFIG_FILES "/sip.ini");
+        server->setValue("uri.conf", CONFIG_FILES "/uri.ini"); 
+#else
 	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
 	server->setValue("uri.conf", CONFIG_FILES "/uri.conf");
+#endif
 }
 
 bool Driver::getDestination(const char *destination, const char *user, char *buf, size_t size)
@@ -264,9 +269,6 @@ void Driver::startDriver(void)
 	const char *cp;
 	unsigned max_count = ts_count;
 	cp = server->getLast("slots.sip");
-#ifdef	HAVE_EXOSIP2
-	int rtn;
-#endif
 
 	exiting = false;
 	timeslot = ts_used;
@@ -282,39 +284,6 @@ void Driver::startDriver(void)
 	if(!count)
 		return;
 
-#ifdef	HAVE_EXOSIP2
-	eXosip_init();
-
-	for(;;)
-	{
-		cp = getLast("transport");
-		if(!cp)
-			cp = "udp";
-
-		if(!stricmp(cp, "tcp"))
-			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 0);
-		else if(!stricmp(cp, "tls"))
-			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 1);
-		else
-			rtn = eXosip_listen_addr(IPPROTO_UDP, NULL, sip_port, AF_INET, 0);
-
-		if(!rtn)
-			break;
-
-		slog.error("sip: failed to bind %d", sip_port);
-		if(tries++ > 3)
-		{
-			eXosip_quit();
-			return;
-		}
-		sip_port += 10;
-		if(!getLast("rtp"))
-			rtp_port += 10;
-	}
-
-	eXosip_automatic_action();
-
-#else
 	while(eXosip_init(NULL, NULL, sip_port))
 	{
 		slog.error("sip: failed to bind %d", sip_port);
@@ -324,7 +293,6 @@ void Driver::startDriver(void)
 		if(!getLast("rtp"))
 			rtp_port += 10;
 	}
-#endif
 
 	cp = getLast("interface");
 	if(!cp)
@@ -336,17 +304,16 @@ void Driver::startDriver(void)
 	setValue("interface", cbuf);
 	
         osip_trace_initialize_syslog(TRACE_LEVEL0, "bayonne");
-        osip_trace_enable_level(TRACE_LEVEL1);
+/*        osip_trace_enable_level(TRACE_LEVEL1);
         osip_trace_enable_level(TRACE_LEVEL2);
         osip_trace_enable_level(TRACE_LEVEL3);
         osip_trace_enable_level(TRACE_LEVEL4);
         osip_trace_enable_level(TRACE_LEVEL5);
         osip_trace_enable_level(TRACE_LEVEL6);
         osip_trace_enable_level(TRACE_LEVEL7);
+*/
 
-#ifndef	HAVE_EXOSIP2
 	eXosip_sdp_negotiation_remove_audio_payloads();
-#endif
 
 	switch(info.encoding)
 	{
@@ -387,11 +354,9 @@ void Driver::startDriver(void)
 		return;
 	}
 
-#ifndef	HAVE_EXOSIP2
 	eXosip_sdp_negotiation_add_codec(
 		strdup(getLast("payload")), NULL, strdup("RTP/AVP"), 
 		NULL, NULL, NULL, NULL, NULL, strdup(cbuf));
-#endif
 
 	slog.debug("sip: adding sdp encoding %s", cbuf);
 	info.annotation = strdup(cbuf);
@@ -401,16 +366,13 @@ void Driver::startDriver(void)
 		snprintf(cbuf, sizeof(cbuf), "%d telephony-event/%d", 
 			dtmf_payload, info.rate);
 		slog.debug("sip: adding sdp encoding %s", cbuf);
-#ifndef	HAVE_EXOSIP2
 		eXosip_sdp_negotiation_add_codec(
 			strdup(getLast("dtmf")), NULL, strdup("RTP/AVP"), 
 			NULL, NULL, NULL, NULL, NULL, strdup(cbuf));
-#endif
 	}
 
 	eXosip_set_user_agent("GNU Bayonne");
 
-#ifndef	HAVE_EXOSIP2
 	cp = getLast("local");
 	if(cp)
 	{
@@ -424,7 +386,6 @@ void Driver::startDriver(void)
 		InetAddress fa = cp;
 		eXosip_set_firewallip(fa.getHostname());
 	}
-#endif
 
 	slog.debug("sip: bound to port %d", sip_port);
 	msgport->start();
@@ -488,10 +449,6 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	char *uri;
 	long mult = 60000;
 
-#ifdef	HAVE_EXOSIP2
-	  osip_message_t *msg = NULL; 
-#endif
-
 	if(!ScriptChecks::useKeywords(line, "=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"))
 		return "invalid keywords for sip, use uri, timeout, proxy, userid, secret, port";
 
@@ -615,11 +572,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 
 	eXosip_lock();
 
-#ifdef	HAVE_EXOSIP2
-	reg->regid = eXosip_register_build_initial_register((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact, reg->duration / 1000, &msg);
-#else
 	reg->regid = eXosip_register_init((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact);
-#endif
 
 	if(reg->regid < 0)
 	{
@@ -627,33 +580,11 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		return "cannot create sip registration";
 	}
 
-#ifdef	HAVE_EXOSIP2
-	osip_message_set_supported(msg, "path");   
-
-	cp = getLast("transport");
-	if(!stricmp(cp, "tcp"))
-		eXosip_transport_set(msg, "TCP"); 
-	else if(!stricmp(cp, "tls"))
-		eXosip_transport_set(msg, "TLS");
-
-/*
-	reg->route = ScriptChecks::findKeyword(line, "route");
-	if(reg->route && reg->route[0])
-	{
-		char *hdr = osip_strdup(reg->route);
-		osip_message_set_multiple_header(msg, hdr, reg->route);
-		osip_free(hdr);
-	}
-*/
-
-	eXosip_register_send_register(reg->regid, msg);
-#else
 	if(eXosip_register(reg->regid, reg->duration / 1000) < 0)
 	{
 		eXosip_unlock();
 		return "cannot register with sip proxy";
 	}
-#endif
 	eXosip_unlock();
 
 	reg->setTimer(reg->duration / 2 - 1000);
@@ -739,9 +670,7 @@ bool Driver::authenticate(Session *s)
 		goto unlock;
 	}
 
-#ifndef	HAVE_EXOSIP2
 	eXosip_retry_call(s->cid);
-#endif
 	rtn = true;
 
 unlock:
@@ -782,18 +711,7 @@ void Driver::refresh(void)
 		slog.debug("refreshing %s", reg->contact);
 
 		eXosip_lock();
-#ifdef	HAVE_EXOSIP2
-		osip_message_t *msg = NULL; 
-		const char *cp = getLast("transport");
-		eXosip_register_build_register(reg->regid, reg->duration / 1000, &msg);
-		if(!stricmp(cp, "tcp"))
-			eXosip_transport_set(msg, "TCP");
-		else if(!stricmp(cp, "tls"))
-			eXosip_transport_set(msg, "TLS");
-		eXosip_register_send_register(reg->regid, msg);		
-#else
 		eXosip_register(reg->regid, reg->duration / 1000);
-#endif
 		eXosip_unlock();
 		reg->setTimer(reg->duration / 2 - 1000);
 	}
@@ -924,11 +842,7 @@ void Driver::run(void)
                         event.id = CALL_ANSWERED;
                         session->postEvent(&event);
                         break;  
-#ifdef	HAVE_EXOSIP2
-		case EXOSIP_CALL_INVITE:
-#else
 		case EXOSIP_CALL_NEW:
-#endif
 			dialed = sevent->req_uri;
 
 			snprintf(cbuf, sizeof(cbuf), "%s", sevent->remote_uri);
