@@ -88,30 +88,6 @@ void Session::setDTMFMode(const char *mode)
 	}
 }		
 
-#ifdef	HAVE_EXOSIP2
-
-void Session::sendDTMFInfo(char digit, unsigned duration)
-{
-	osip_message_t *message = NULL;
-	char dtmf_body[1000];
-
-        snprintf(dtmf_body, sizeof(dtmf_body) - 1,
-                "Signal=%c\r\nDuration=%d\r\n", digit, duration);  
-
-	eXosip_lock();
-	if(eXosip_call_build_info(did, &message) != 0)
-	{
-		eXosip_unlock();
-		return;
-	}
-
-	osip_message_set_body(message, dtmf_body, strlen(dtmf_body));
-	osip_message_set_content_type(message, "application/dtmf-relay");
-	eXosip_call_send_request(did, message);
-	eXosip_unlock();
-}
-
-#else
 void Session::sendDTMFInfo(char digit, unsigned duration)
 {
 	char dtmf_body[1000];
@@ -122,8 +98,6 @@ void Session::sendDTMFInfo(char digit, unsigned duration)
         eXosip_unlock();
 }
 
-#endif
-
 timeout_t Session::getRemaining(void)
 {
 	return TimerPort::getTimer();
