@@ -92,12 +92,7 @@ static Keydata::Define paths[] = {
 #endif
 	{NULL, NULL}};
 
-static Keydata::Define gateway[] = {
-	{"binding", "troll"},
-	{NULL, NULL}};
-
 static Keydata::Define server[] = {
-	{"argv0", "bayonne"},
 	{"user", "bayonne"},
 	{"group", "bayonne"},
 	{"language", "none"},
@@ -106,11 +101,7 @@ static Keydata::Define server[] = {
 	{"state", "init"},
 	{"logging", "warn"},
 	{"monitoring", "tcp"},
-	{"binding", "ivrscript"},
-	{NULL, NULL}};
-
-static Keydata::Define switchkeys[] = {
-	{"timeslots", "32"},
+	{"binding", "ivrscript1"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
@@ -120,96 +111,20 @@ static Keydata::Define engine[] = {
 	{"server", "localhost"},
 	{"userid", ""},
 	{"secret", ""},
+	{"timeslots", "32"},
 	{NULL, NULL}};
 
 #ifdef	WIN32
 Keydata keypaths(paths, "/bayonne/paths");
 Keydata keyserver(server, "/bayonne/server");
 Keydata keyengine(engine, "/bayonne/engine");
-Keydata keyswitch(switchkeys, "/bayonne/switch");
-Keydata keygateway(gateway, "/bayonne/gateway");
 #else
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
-Keydata keyswitch(switchkeys, "/bayonne/server/switch");
-Keydata keygateway(gateway, "/bayonne/server/gateway");
 #endif
 Keydata keyoptions;
 
-bool loadBinder(const char *path)
-{
-        char pathbuf[256];
-        const char *cp, *kv;
-        const char *prefix = NULL;
-        DSO *dso;  
-
-#ifdef  WIN32
-#ifdef  HAVE_TESTING
-        if(!prefix && Bayonne::provision_test)
-#ifdef  NDEBUG
-                prefix = "DEBUG";
-#else    
-                prefix = "RELEASE";
-#endif
-#endif   
-        if(!prefix)
-	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binder";
-#else
-
-#ifdef  HAVE_TESTING
-        char prefixbuf[256];
-
-        if(!prefix && Bayonne::provision_test && !strchr(path, '/'))
-        {
-                snprintf(prefixbuf, sizeof(prefixbuf),
-                        "%s/binders/%s/.libs", SOURCE_FILES, path);
-                if(!isDir(prefixbuf))
-                        snprintf(prefixbuf, sizeof(prefixbuf),
-                                "%s/binders/%s", SOURCE_FILES, path);
-                prefix = prefixbuf;
-        }
-#endif
-        if(!prefix)
-                prefix = LIBDIR_FILES;
-#endif 
-
-#ifdef  WIN32
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
-#else
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
-#endif  
-
-        cp = path;
-        path = pathbuf;
-
-        kv = runtime.getLast(path); 
-
-        if(kv)
-        {
-                if(!stricmp(kv, "loaded"))
-                        return true;
-                return false;
-        }
-
-        if(!canAccess(path))
-        {
-                Bayonne::errlog("access", "cannot load %s", path);
-                return false;
-        }  
-
-        dso = new DSO(path);
-        if(!dso->isValid())
-        {
-                kv = dso->getError();
-                runtime.setValue(path, kv);
-                Bayonne::errlog("error", "cannot initialize %s", path);
-                return false;
-        }
-        runtime.setValue(path, "loaded");
-        return true;
-}                     
-
 void liveConfig(void)
 {
 	char path[256];
@@ -217,8 +132,7 @@ void liveConfig(void)
 	const char *env;
 	char *p;
 	const char *cp;
-	unsigned timeslots = atoi(keyswitch.getLast("timeslots"));
-	const char *argv0 = keyserver.getLast("argv0");
+	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 
 #ifdef	WIN32
         char nodename[MAX_COMPUTERNAME_LENGTH + 1];
@@ -283,14 +197,14 @@ void liveConfig(void)
 	if(!userid || !stricmp(userid, "root"))
 		userid="bayonne";	
 
-	snprintf(path, sizeof(path), "/tmp/%s-%s", argv0, userid);
+	snprintf(path, sizeof(path), "/tmp/bayonne-%s", userid);
 	keypaths.setValue("tmp", path);
 	purgedir(path);
 	Dir::create(path);
 
 	if(canModify("/dev/shm"))
 	{
-		snprintf(path, sizeof(path), "/dev/shm/%s-%s", argv0, userid);
+		snprintf(path, sizeof(path), "/dev/shm/bayonne-%s", userid);
 		keypaths.setValue("tmpfs", path);
 		purgedir(path);
 		Dir::create(path);
@@ -300,6 +214,10 @@ void liveConfig(void)
 
 #endif
 	cp = keyoptions.getLast("prefix");
+#ifdef	WIN32
+	if(Bayonne::provision_test)
+		cp = NULL;
+#endif
 	if(cp && *cp)
 		chdir(cp);
 
@@ -323,7 +241,11 @@ void liveConfig(void)
 		if(isalpha(lang[0]) && isalpha(lang[1]))
 			keyserver.setValue("language", lang);
 	}
+#ifdef	WIN32
+	snprintf(path, sizeof(path), "%s/tones.ini", keypaths.getLast("config"));
+#else
 	snprintf(path, sizeof(path), "%s/tones.conf", keypaths.getLast("config"));
+#endif
 	TelTone::load(path);
 	keypaths.setValue("tones", path);
 
@@ -445,9 +367,9 @@ void testConfig(char *argv0)
 	keypaths.setValue("datafiles", "tempfiles");
 	keypaths.setValue("logfiles", "tempfiles");
 	keypaths.setValue("runfiles", "tempfiles");
-	Process::setEnv("DRIVERCONFIG", "../config/driver.conf", true);
-	Process::setEnv("MODULECONFIG", "../config/module.conf", true);
-	Process::setEnv("SPANCONFIG", "../config/spans.conf", true);
+	Process::setEnv("DRIVERCONFIG", "../config/driver.ini", true);
+	Process::setEnv("MODULECONFIG", "../config/module.ini", true);
+	Process::setEnv("SPANCONFIG", "../config/spans.ini", true);
 #else
 	char pbuf[256];
 	getcwd(pbuf, sizeof(pbuf));
@@ -480,15 +402,15 @@ void loadConfig(void)
 	char pbuf[256];
 	const char *config = keypaths.getLast("config");
 
-	snprintf(pbuf, sizeof(pbuf), "%s/server.conf", config); 
+	snprintf(pbuf, sizeof(pbuf), "%s/server.ini", config); 
 	keypaths.loadFile(pbuf, "paths");
 	keyserver.loadFile(pbuf, "server");
 	keyengine.loadFile(pbuf, "engine");
 	runtime.loadFile(pbuf, "virtual", "virtual");
 
-	snprintf(pbuf, sizeof(pbuf), "%s/driver.conf", config);
+	snprintf(pbuf, sizeof(pbuf), "%s/driver.ini", config);
 	Process::setEnv("DRIVERCONFIG", pbuf, true); 
-	snprintf(pbuf, sizeof(pbuf), "%s/module.conf", config);
+	snprintf(pbuf, sizeof(pbuf), "%s/module.ini", config);
 	Process::setEnv("MODULECONFIG", pbuf, true);
 
 //	Process::setGroup(keyserver.getLast("group"));
@@ -517,8 +439,6 @@ void loadConfig(void)
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
-		keyswitch.load("~bayonne/switch");
-		keygateway.load("~bayonne/gateway");
 		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
@@ -527,8 +447,6 @@ void loadConfig(void)
 		keypaths.load("/bayonne/provision/paths");
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
-		keyswitch.load("/bayonne/provision/switch");
-		keygateway.load("/bayonne/provision/gateway");
 		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
@@ -605,7 +523,7 @@ retry:
 #ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
-		keyoptions.setValue("driver", option + 8);
+		keyengine.setValue("driver", option + 8);
 		++argv;
 		goto retry;
 	} 
@@ -613,32 +531,14 @@ retry:
         if(!strnicmp(option, "-bind=", 6))
         {
                 keyserver.setValue("binding", option + 6);    
-		keygateway.setValue("bidning", option + 6);
                 ++argv;
                 goto retry;
         }  
 
-        if(!strnicmp(option, "-trunking=", 10))
-        {
-                keyswitch.setValue("trunking", option + 10);    
-		keygateway.setValue("trunking", option + 10);
-                ++argv;
-                goto retry;
-        }
-
-
-
-        if(!strnicmp(option, "-protocol=", 10))
-        {
-                keyswitch.setValue("protocol", option + 10);  
-                ++argv;
-                goto retry;
-        }  
-            
         if(!strnicmp(option, "-test=", 6))
         {
 		testConfig(argv0);
-                keyoptions.setValue("driver", option + 6);
+                keyengine.setValue("driver", option + 6);
                 ++argv;
                 goto retry;
         }  
@@ -652,7 +552,7 @@ retry:
 			exit(-1);
 		}
 		testConfig(argv0);
-		keyoptions.setValue("driver", *(argv++));
+		keyengine.setValue("driver", *(argv++));
 		goto retry;
 	}
 
@@ -743,8 +643,7 @@ retry:
 
         if(!strnicmp(option, "-timeslots=", 11))
         {
-		keyswitch.setValue("timeslots", option + 11);
-		keygateway.setValue("timeslots", option + 11);
+		keyengine.setValue("timeslots", option + 11);
                 ++argv;
                 goto retry;
         }
@@ -832,7 +731,7 @@ retry:
 			cerr << "bayonne: -driver: missing argument" << endl;
                         exit(-1);
                 }
-                keyoptions.setValue("driver", *(argv++));
+                keyengine.setValue("driver", *(argv++));
                 goto retry;
         }
 
@@ -845,37 +744,10 @@ retry:
                         exit(-1);
                 }
                 keyserver.setValue("binding", *argv);
-		keygateway.setValue("binding", *argv);
 		++argv;
                 goto retry;
         } 
 
-        if(!stricmp(option, "-trunking"))
-        {
-                ++argv;
-                if(!*argv)
-                {
-                        cerr << "bayonne: -trunking: missing argument" << endl;
-                        exit(-1);
-                }
-                keyswitch.setValue("trunking", *argv);
-		keygateway.setValue("trunking", *argv);
-		++argv;
-                goto retry;
-        }  
-
-        if(!stricmp(option, "-protocol"))
-        {
-                ++argv;
-                if(!*argv)
-                {
-                        cerr << "bayonne: -protocol: missing argument" << endl;
-                        exit(-1);
-                }
-                keyswitch.setValue("protocol", *(argv++));
-                goto retry;
-        }  
-
         if(!stricmp(option, "-timeslots"))
         {
                 ++argv;
@@ -884,8 +756,7 @@ retry:
 			cerr << "bayonne: -timeslots: missing argument" << endl;
                         exit(-1);
                 }
-		keyswitch.setValue("timeslots", *argv);
-		keygateway.setValue("timeslots", *argv);
+		keyengine.setValue("timeslots", *argv);
 		++argv;
                 goto retry;
 	}
