@@ -148,7 +148,6 @@ class Runtime : public ScriptRuntime, public Bayonne
 protected:
         unsigned long getTrapMask(const char *trapname);
 
-	static bool testNumber(ScriptInterp *interp, const char *v);
 	static bool testFile(ScriptInterp *interp, const char *v);
 	static bool testDir(ScriptInterp *interp, const char *v);
 	static bool testTimeslot(ScriptInterp *interp, const char *v);
@@ -172,6 +171,8 @@ public:
 
 	bool isInput(Line *line);
 
+	bool loadBinder(const char *id);
+
 	Runtime();
 };
 
@@ -202,8 +203,9 @@ public:
 	bool scrReadpath(void);
 	bool scrWritepath(void);
 	bool scrVoicelib(void);
-	bool scrMenu(void);
-	bool scrEndmenu(void);
+	bool scrForm(void);
+	bool scrEndform(void);
+	bool scrEndinput(void);
 	bool scrLibexec(void);
 	bool scrPlay(void);
 	bool scrReplay(void);
@@ -221,6 +223,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+        const char *chkEndinput(Line *line, ScriptImage *img); 
 	const char *chkBGM(Line *line, ScriptImage *img);
 	const char *chkList(Line *line, ScriptImage *img);
 	const char *chkConfig(Line *line, ScriptImage *img);
@@ -255,15 +258,12 @@ extern Runtime runtime;
 extern Keydata keypaths;
 extern Keydata keyserver;
 extern Keydata keyengine;
-extern Keydata keyswitch;
-extern Keydata keygateway;
 extern Keydata keyoptions;
 
 extern TimeslotProperty typeTimeslot;
 extern PositionProperty typePosition;
 
 void purgedir(const char *dir);
-bool loadBinder(const char *id);
 void loadConfig(void);
 void liveConfig(void);
 void dumpConfig(Keydata &keydef);
